@@ -43,19 +43,6 @@ public:
   // used by python __repr__
   std::string repr() const;
 
-  // returns a floating point number that compares unequal (and unordered) to any other number
-  // thus the following all evaluate to true: never() != never(), !(x < never()), !(x >= never()) (so be careful!)
-  static double never();
-
-  // this MUST be used to correctly compare against never since NaN != NaN
-  static bool isnever(double t);
-
-  // returns a floating point number that compares less than any other number
-  static double distant_past();
-
-  // returns a floating point number that compares greater than any other number
-  static double far_future();
-
 private:
   double m_start; 
   double m_end;
@@ -65,5 +52,20 @@ private:
   std::vector<size_t> m_checkpoints;
 };
 
+namespace time {
+  
+  // returns a floating point number that compares unequal (and unordered) to any other number
+  // thus the following all evaluate to true: never() != never(), !(x < never()), !(x >= never()) (so be careful!)
+  double never();
+
+  // this MUST be used to correctly compare against never since NaN != NaN
+  bool isnever(double t);
+
+  // returns a floating point number that compares less than any other number
+  double distant_past();
+
+  // returns a floating point number that compares greater than any other number
+  double far_future();
+}
 
 }
\ No newline at end of file
